[Python-checkins] [Enum] fix typo (GH-94158)

ethanfurman webhook-mailer at python.org
Thu Jun 23 10:48:34 EDT 2022


https://github.com/python/cpython/commit/b4e0d6124a848a22df1ba12891329242c9e96f11
commit: b4e0d6124a848a22df1ba12891329242c9e96f11
branch: main
author: Ethan Furman <ethan at stoneleaf.us>
committer: ethanfurman <ethan at stoneleaf.us>
date: 2022-06-23T07:48:25-07:00
summary:

[Enum] fix typo (GH-94158)

files:
M Lib/enum.py

diff --git a/Lib/enum.py b/Lib/enum.py
index 8d0982a218d76..a41422cc61696 100644
--- a/Lib/enum.py
+++ b/Lib/enum.py
@@ -1205,21 +1205,21 @@ def __new__(cls, value):
     def __init__(self, *args, **kwds):
         pass
 
-    def _generate_next_value_(name, start, count, last_value):
+    def _generate_next_value_(name, start, count, last_values):
         """
         Generate the next value when not given.
 
         name: the name of the member
         start: the initial start value or None
         count: the number of existing members
         last_value: the list of values assigned
         """
-        if not last_value:
+        if not last_values:
             return start
         try:
-            last = last_value[-1]
-            last_value.sort()
-            if last == last_value[-1]:
+            last = last_values[-1]
+            last_values.sort()
+            if last == last_values[-1]:
                 # no difference between old and new methods
                 return last + 1
             else:
@@ -1233,7 +1233,7 @@ def _generate_next_value_(name, start, count, last_value):
                     DeprecationWarning,
                     stacklevel=3,
                     )
-            for v in last_value:
+            for v in last_values:
                 try:
                     return v + 1
                 except TypeError:
@@ -1389,7 +1389,7 @@ def _generate_next_value_(name, start, count, last_values):
         name: the name of the member
         start: the initial start value or None
         count: the number of existing members
         last_value: the last value assigned or None
         """
         if not count:
             return start if start is not None else 1
@@ -1205,21 +1205,21 @@ def __new__(cls, value):
         start: the initial start value or None
         count: the number of existing members
-        last_value: the list of values assigned
+        last_values: the list of values assigned
         """
@@ -1389,7 +1389,7 @@ def _generate_next_value_(name, start, count, last_values):
         start: the initial start value or None
         count: the number of existing members
-        last_value: the last value assigned or None
+        last_values: the last value assigned or None
         """
         if not count:



More information about the Python-checkins mailing list